@@ -1,16 +1,18 @@
-use crate::types::ErrBox;
+use anyhow::bail;
+use anyhow::Result;
 
 pub fn get_sha256_checksum(bytes: &[u8]) -> String {
-  use sha2::{Digest, Sha256};
+  use sha2::Digest;
+  use sha2::Sha256;
   let mut hasher = Sha256::new();
   hasher.update(bytes);
   format!("{:x}", hasher.finalize())
 }
 
-pub fn verify_sha256_checksum(bytes: &[u8], checksum: &str) -> Result<(), ErrBox> {
+pub fn verify_sha256_checksum(bytes: &[u8], checksum: &str) -> Result<()> {
   let bytes_checksum = get_sha256_checksum(bytes);
   if bytes_checksum != checksum {
-    err!("The checksum {} did not match the expected checksum of {}.", bytes_checksum, checksum)
+    bail!("The checksum {} did not match the expected checksum of {}.", bytes_checksum, checksum)
   } else {
     Ok(())
   }
